pub struct RolloutManager { /* private fields */ }Expand description
Manages rollout persistence for a single session.
Implementations
Sourceimpl RolloutManager
impl RolloutManager
Sourcepub fn new(session_dir: PathBuf) -> Result<Self, RolloutError>
pub fn new(session_dir: PathBuf) -> Result<Self, RolloutError>
Create a new manager rooted at session_dir.
Sourcepub fn record(&mut self, entry: &RolloutEntry) -> Result<(), RolloutError>
pub fn record(&mut self, entry: &RolloutEntry) -> Result<(), RolloutError>
Serialize entry, separating large payloads, and append it to the log.
Sourcepub fn load(dir: &Path) -> Result<Vec<RolloutEntry>, RolloutError>
pub fn load(dir: &Path) -> Result<Vec<RolloutEntry>, RolloutError>
Load all entries previously written to dir/rollout/events.jsonl.
Sourcepub fn close(&mut self) -> Result<(), RolloutError>
pub fn close(&mut self) -> Result<(), RolloutError>
Flush pending writes and mark the rollout as complete.