pub struct AgentRouter { /* private fields */ }Expand description
Routes agent names to configured models, falling back to a default.
Implementations
Sourceimpl AgentRouter
impl AgentRouter
Sourcepub fn new(default_model: String) -> Self
pub fn new(default_model: String) -> Self
Create a new agent router with the given default model.
Sourcepub fn register(&mut self, route: AgentRoute)
pub fn register(&mut self, route: AgentRoute)
Register a route for an agent.
Sourcepub fn route_for_agent(&self, agent_name: &str) -> &str
pub fn route_for_agent(&self, agent_name: &str) -> &str
Return the model for the named agent, falling back to the default.